desktop constant
double
const desktop
Width at which the device transitions to desktop (default: 1200px)
Implementation
static const double desktop = 1200;
Width at which the device transitions to desktop (default: 1200px)
static const double desktop = 1200;