isDesktop property
bool
get
isDesktop
Check if screen width is in desktop range (>= desktopBreakpoint).
Implementation
bool get isDesktop => screenWidth >= _config.desktopBreakpoint;
Check if screen width is in desktop range (>= desktopBreakpoint).
bool get isDesktop => screenWidth >= _config.desktopBreakpoint;