Breakpoints class
Defines the default screen width breakpoints for adaptive UI changes.
These static constants serve as compile-time defaults. For runtime customization, use AdaptiFlow with AdaptiFlowData instead.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- desktop → const double
- Width at which the device transitions to desktop (default: 1200px)
- mobile → const double
- Width below which the device is considered mobile (default: 600px)
- tablet → const double
-
Intermediate tablet breakpoint (default: 900px).
Used by
adaptiveConstrainedfor tablet max width. - widescreen → const double
- Width at which the device is considered widescreen (default: 1920px)