ResponsiveConstraints extension
Extension on Widget to prevent content overflow on large screens.
- on
Methods
-
adaptiveConstrained(
BuildContext context) → Widget -
Available on Widget, provided by the ResponsiveConstraints extension
Responsive constraint based on device type, using config-driven max widths. -
constrained(
{double maxWidth = 800}) → Widget -
Available on Widget, provided by the ResponsiveConstraints extension
Centers the widget and ensures its width does not exceedmaxWidth. -
constrainedBoth(
{double maxWidth = 800, double maxHeight = 600}) → Widget -
Available on Widget, provided by the ResponsiveConstraints extension
Constrains widget with both max width and height.