SafeResponsiveLayout class
A safe layout wrapper that handles common overflow and safe area concerns.
Wraps content in SafeArea + optional SingleChildScrollView with keyboard-aware bottom padding. Works on all device types.
Handles:
- Device notches and status bars (SafeArea)
- Content overflow (SingleChildScrollView)
- Keyboard overlay (bottom padding from
viewInsets) - Optional max width/height constraints
SafeResponsiveLayout(
padding: EdgeInsets.symmetric(horizontal: context.wp(5)),
child: Column(children: [...]),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SafeResponsiveLayout
- Available extensions
Constructors
- SafeResponsiveLayout({Key? key, required Widget child, EdgeInsets? padding, bool maintainBottomViewPadding = true, bool enableScroll = true, double? maxWidth, double? maxHeight, ScrollPhysics? physics})
-
const
Properties
- child → Widget
-
The child widget to wrap.
final
- enableScroll → bool
-
Whether to wrap content in a SingleChildScrollView (default: true).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maintainBottomViewPadding → bool
-
Whether to maintain bottom view padding in SafeArea (default: true).
final
- maxHeight → double?
-
Optional maximum height constraint.
final
- maxWidth → double?
-
Optional maximum width constraint. Useful for centering content on
wide screens (e.g., tablets, desktops).
final
- padding → EdgeInsets?
-
Optional padding around the child.
final
- physics → ScrollPhysics?
-
Optional scroll physics for the SingleChildScrollView.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adaptiveConstrained(
BuildContext context) → Widget -
Available on Widget, provided by the ResponsiveConstraints extension
Responsive constraint based on device type, using config-driven max widths. -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
constrained(
{double maxWidth = 800}) → Widget -
Available on Widget, provided by the ResponsiveConstraints extension
Centers the widget and ensures its width does not exceedmaxWidth. -
constrainedBoth(
{double maxWidth = 800, double maxHeight = 600}) → Widget -
Available on Widget, provided by the ResponsiveConstraints extension
Constrains widget with both max width and height. -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited